@@ -1538,24 +1538,24 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
     # for the analysed period.
 
     if (aggregate_function_env_data_primary == 'median'){
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
+      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                             (as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
     } else if (aggregate_function_env_data_primary == 'sum'){
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
+      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                             (as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
     } else if (aggregate_function_env_data_primary == 'mean'){
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
+      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                             (as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
 
     } else if (aggregate_function_env_data_primary == 'min'){
 
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , min, na.rm = TRUE))
+      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                             (as.numeric(plot_column)), drop = FALSE]),1 , min, na.rm = TRUE))
 
     } else if (aggregate_function_env_data_primary == 'max'){
 
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , max, na.rm = TRUE))
+      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                             (as.numeric(plot_column)), drop = FALSE]),1 , max, na.rm = TRUE))
 
     } else {
       stop(paste0("aggregate function for env_data_primary is ", aggregate_function_env_data_primary, ". Instead it should be mean, median, sum, min or max."))
@@ -1563,20 +1563,20 @@ daily_response_seascorr <- function(response, env_data_primary, env_data_control
 
 
     if (aggregate_function_env_data_control == 'median'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
+      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                                (as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
     } else if (aggregate_function_env_data_control == 'sum'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
+      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                                (as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
     } else if (aggregate_function_env_data_control == 'mean'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
+      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                                (as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
     } else if (aggregate_function_env_data_control == 'min'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , min, na.rm = TRUE))
+      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                                (as.numeric(plot_column)), drop = FALSE]),1 , min, na.rm = TRUE))
     } else if (aggregate_function_env_data_control == 'max'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , max, na.rm = TRUE))
+      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                                (as.numeric(plot_column)), drop = FALSE]),1 , max, na.rm = TRUE))
     } else {
 
       stop(paste0("aggregate function for env_data_control is ", aggregate_function_env_data_control, ". Instead it should be mean, median, sum, min or max."))
