@@ -1,7 +1,7 @@
 #' @method plot dmrs
 #' @export
 
-plot.dmrs <- function(x, ..., type = 1){
+plot.dmrs <- function(x, ..., type = 2){
 
 if (type == 1){
 
@@ -11,13 +11,9 @@ if (type == 1){
 
   plot_out <- x[["plot_heatmap"]]
 
-} else if (type == 3){
-
-  plot_out <- x[["plot_specific"]]
-
 } else {
 
-  stop(paste0("type should be on of 1, 2 or 3, but instead it is ", type, "!"))
+  stop(paste0("type should be 1 or 2, but instead it is ", type, "!"))
 }
 
   return(plot_out)
