@@ -1400,31 +1400,34 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     ## Once again, the same procedure, to get the optimal sequence, but this time for whole data, not only
     # for the analysed period.
 
-    if (aggregate_function_env_data_primary == 'median'){
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
-    } else if (aggregate_function_env_data_primary == 'sum'){
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
-    } else if (aggregate_function_env_data_primary == 'mean'){
-      x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                             as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
-    } else {
-      stop(paste0("aggregate function for env_data_primary is ", aggregate_function_env_data_primary, ". Instead it should be mean, median or sum."))
-    }
+      ## Once again, the same procedure, to get the optimal sequence, but this time for whole data, not only
+      # for the analysed period.
 
-    if (aggregate_function_env_data_control == 'median'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
-    } else if (aggregate_function_env_data_control == 'sum'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
-    } else if (aggregate_function_env_data_control == 'mean'){
-      x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - (as.numeric(row_index) + 1):
-                                                                                as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
-    } else {
-      stop(paste0("aggregate function for env_data_control is ", aggregate_function_env_data_control, ". Instead it should be mean, median or sum."))
-    }
+      if (aggregate_function_env_data_primary == 'median'){
+        x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                               (as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
+      } else if (aggregate_function_env_data_primary == 'sum'){
+        x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                               (as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
+      } else if (aggregate_function_env_data_primary == 'mean'){
+        x1_original <- data.frame(apply(data.frame(env_data_primary_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                               (as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
+      } else {
+        stop(paste0("aggregate function for env_data_primary is ", aggregate_function_env_data_primary, ". Instead it should be mean, median or sum."))
+      }
+
+      if (aggregate_function_env_data_control == 'median'){
+        x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                               (as.numeric(plot_column)), drop = FALSE]),1 , median, na.rm = TRUE))
+      } else if (aggregate_function_env_data_control == 'sum'){
+        x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                               (as.numeric(plot_column)), drop = FALSE]),1 , sum, na.rm = TRUE))
+      } else if (aggregate_function_env_data_control == 'mean'){
+        x2_original <- data.frame(apply(data.frame(env_data_control_original[, (as.numeric(plot_column) - as.numeric(row_index) + 1):
+                                                                               (as.numeric(plot_column)), drop = FALSE]),1 , mean, na.rm = TRUE))
+      } else {
+        stop(paste0("aggregate function for env_data_control is ", aggregate_function_env_data_control, ". Instead it should be mean, median or sum."))
+      }
 
 }
 
