@@ -31,13 +31,13 @@
 #' Example1 <- daily_response(response = example_proxies_1,
 #' env_data = LJ_daily_temperatures, method = "lm", metric = "r.squared",
 #' fixed_width = 90, previous_year = TRUE, row_names_subset = TRUE)
-#' plot_extreme(Example1)
+#' # plot_extreme(Example1)
 #'
 #' Example2 <- daily_response(response = example_proxies_1,
 #' env_data = LJ_daily_temperatures, method = "brnn",
 #' metric = "adj.r.squared", lower_limit = 50, upper_limit = 55, neurons = 1,
 #' row_names_subset = TRUE, previous_year = TRUE)
-#' plot_extreme(Example2)
+#' # plot_extreme(Example2)
 #'
 #' # Example with negative correlations
 #' data(data_TRW_1)
@@ -45,13 +45,13 @@
 #' Example3 <- daily_response(response = data_TRW_1,
 #' env_data = LJ_daily_temperatures_subset, method = "lm", metric = "adj.r.squared",
 #' lower_limit = 35, upper_limit = 40, previous_year = TRUE, row_names_subset = TRUE)
-#' plot_extreme(Example3)
+#' # plot_extreme(Example3)
 #'
 #' Example4 <- daily_response(response = example_proxies_1,
 #' env_data = LJ_daily_temperatures, method = "lm",
 #' metric = "r.squared", lower_limit = 30, upper_limit = 120, neurons = 1,
 #' row_names_subset = TRUE, previous_year = TRUE)
-#' plot_extreme(Example4)
+#' # plot_extreme(Example4)
 #' }
 #'
 #' @keywords internal
@@ -241,18 +241,64 @@ plot_extreme <- function(result_daily_response, title = TRUE, ylimits = NULL, re
   # there are always missing values, which are a result of changing window
   # width calclulations. Those warnings are not important and do not affect
   # our results at all
+
+
+
+
+
+
+
+# Function to find the longest non-NA range
+max_length <- 0
+current_length <- 0
+
+for (value_temp in temporal_vector[,1]) {
+  if (!is.na(value_temp)) {
+    current_length <- current_length + 1
+  } else {
+    if (current_length > max_length) {
+      max_length <- current_length
+    }
+    current_length <- 0
+  }
+}
+
+# Check at the end in case the longest sequence is at the end of the vector
+longest_sequence <- max(max_length, current_length)
+
+
+
+if (longest_sequence > 1){
+
   final_plot <- suppressWarnings(
-  ggplot(temporal_vector, aes(y = temporal_vector,
-    x = seq(1, length(temporal_vector)))) + geom_line(lwd = 1.2) +
-     geom_vline(xintercept = plot_column, col = "red") +
-     scale_x_continuous(breaks = sort(c(seq(0, nrow(temporal_vector), 50)), decreasing = FALSE),
-       labels = sort(c(seq(0, nrow(temporal_vector), 50)))) +
-     scale_y_continuous(limits = ylimits) +
-       annotate("label", label = as.character(calculated_metric),
-         y = calculated_metric, x = plot_column + 15) +
-    annotate("label", label = paste("Day", as.character(plot_column), sep = " "),
-             y = min(temporal_vector, na.rm = TRUE) + 0.2*min(temporal_vector, na.rm = TRUE), x = plot_column + 15) +
-    journal_theme)
+    ggplot(temporal_vector, aes(y = temporal_vector,
+                                x = seq(1, length(temporal_vector)))) + geom_line(linewidth = 1.2) +
+      geom_vline(xintercept = plot_column, col = "red") +
+      scale_x_continuous(breaks = sort(c(seq(0, nrow(temporal_vector), 50)), decreasing = FALSE),
+                         labels = sort(c(seq(0, nrow(temporal_vector), 50)))) +
+      scale_y_continuous(limits = ylimits) +
+      annotate("label", label = as.character(calculated_metric),
+               y = calculated_metric, x = plot_column + 15) +
+      annotate("label", label = paste("Day", as.character(plot_column), sep = " "),
+               y = min(temporal_vector, na.rm = TRUE) + 0.2*min(temporal_vector, na.rm = TRUE), x = plot_column + 15) +
+      journal_theme)
+
+} else {
+
+  final_plot <- suppressWarnings(
+    ggplot(temporal_vector, aes(y = temporal_vector,
+                                x = seq(1, length(temporal_vector)))) + geom_point() +
+      geom_vline(xintercept = plot_column, col = "red") +
+      scale_x_continuous(breaks = sort(c(seq(0, nrow(temporal_vector), 50)), decreasing = FALSE),
+                         labels = sort(c(seq(0, nrow(temporal_vector), 50)))) +
+      scale_y_continuous(limits = ylimits) +
+      annotate("label", label = as.character(calculated_metric),
+               y = calculated_metric, x = plot_column + 15) +
+      annotate("label", label = paste("Day", as.character(plot_column), sep = " "),
+               y = min(temporal_vector, na.rm = TRUE) + 0.2*min(temporal_vector, na.rm = TRUE), x = plot_column + 15) +
+      journal_theme)
+}
+
 
   # If previous_year = TRUE, we add a vertical line with labels of
   # previous and current years
